-- vs
#version 100

#define mul(a,b) a * b

uniform mat4 mWorld;
uniform mat4 mView;
uniform mat4 mProjection;

attribute highp vec3 a_position;
attribute mediump vec2 a_textureUV;

varying mediump vec2 v_textureUV;

void main()
{
    v_textureUV = a_textureUV;   
    gl_Position = mProjection * mView * mWorld * vec4(a_position, 1.0);
}

-- fs
#version 100

#define saturate(x) clamp(x, 0.0, 1.0)

uniform sampler2D sDiffuse;
uniform mediump vec2 texelSize;
uniform lowp vec4 mixColor;

varying mediump vec2 v_textureUV;

void main() 
{ 
	lowp vec4 result = vec4(0, 0, 0, 0);

	lowp vec4 pixelColor = texture2D(sDiffuse, v_textureUV) * mixColor;
	lowp float bright = max(pixelColor.r, max(pixelColor.g, pixelColor.b));
	
	lowp float minPixel = bright;
	
	if (bright > 0.3)
	{
		lowp vec4 atherColor = texture2D(sDiffuse, vec2(v_textureUV.x + 1.0 * texelSize.x, v_textureUV.y));
		minPixel = min(max(atherColor.r, max(atherColor.g, atherColor.b)), minPixel);

		atherColor = texture2D(sDiffuse, vec2(v_textureUV.x + 3.0 * texelSize.x, v_textureUV.y));
		minPixel = min(max(atherColor.r, max(atherColor.g, atherColor.b)), minPixel);

		atherColor = texture2D(sDiffuse, vec2(v_textureUV.x - 1.0 * texelSize.x, v_textureUV.y));
		minPixel = min(max(atherColor.r, max(atherColor.g, atherColor.b)), minPixel);

		atherColor = texture2D(sDiffuse, vec2(v_textureUV.x - 3.0 * texelSize.x, v_textureUV.y));
		minPixel = min(max(atherColor.r, max(atherColor.g, atherColor.b)), minPixel);

		atherColor = texture2D(sDiffuse, vec2(v_textureUV.x, v_textureUV.y + 1.0 * texelSize.y));
		minPixel = min(max(atherColor.r, max(atherColor.g, atherColor.b)), minPixel);

		atherColor = texture2D(sDiffuse, vec2(v_textureUV.x, v_textureUV.y + 3.0 * texelSize.y));
		minPixel = min(max(atherColor.r, max(atherColor.g, atherColor.b)), minPixel);

		atherColor = texture2D(sDiffuse, vec2(v_textureUV.x, v_textureUV.y - 1.0 * texelSize.y));
		minPixel = min(max(atherColor.r, max(atherColor.g, atherColor.b)), minPixel);

		atherColor = texture2D(sDiffuse, vec2(v_textureUV.x, v_textureUV.y - 3.0 * texelSize.y));
		minPixel = min(max(atherColor.r, max(atherColor.g, atherColor.b)), minPixel);
		
		lowp float atherBright = bright - minPixel;
		if (atherBright > 0.15 && minPixel > 0.2) 
            result = pixelColor;
	}
	
	result = saturate(result) * 0.4;
	result.a = 1.0;

	gl_FragColor = result;
}
