-- vs
#version 100

#define mul(a,b) a * b

// Matricies
uniform mat4 mWorld;
uniform mat4 mView;
uniform mat4 mProjection;

attribute highp vec3 a_position;
attribute mediump vec3 a_normal;
attribute mediump vec2 a_textureUV;
uniform lowp vec4 a_fogColor;
uniform highp float a_fogDensity;

varying mediump vec2 v_textureUV;
varying mediump vec3 v_normal;
varying lowp float v_fogFactor;
varying lowp vec4 v_fogColor;

void main()
{
    v_textureUV = a_textureUV * vec2(1.0, 0.5);
	v_normal  = normalize(mWorld * vec4(a_normal, 1.0)).xyz;

    highp vec4 point = mProjection * mView * mWorld * vec4(a_position, 1.0);
    gl_Position = point;
    v_fogColor = a_fogColor;
    v_fogFactor = clamp(1.0 - exp(point.z * a_fogDensity), 0.0, 1.0);
}

-- fs
#version 100

#define saturate(x) clamp(x, 0.0, 1.0)

// params
uniform lowp float fMaterialSpecularLevel;
uniform lowp vec4 f4ClorSelfIllumination;

// Textures
uniform sampler2D sDiffuse;

//camera view
uniform mediump vec3 specDirection;

// Lights
uniform mediump vec3 lightsDirection;
uniform lowp vec4 lightsDiffuse;
uniform lowp vec4 lightsSpecular;
uniform lowp vec4 lightsAmbient;

uniform lowp vec4 mixColor;

uniform lowp float fContrast;
uniform lowp float fBright;

varying mediump vec2 v_textureUV;
varying mediump vec3 v_normal;
varying lowp float v_fogFactor;
varying lowp vec4 v_fogColor;

void main() 
{
	mediump vec2 roundedUV = mod(v_textureUV, vec2(1.0, 0.5));
    lowp vec4 diffuseColorTex = texture2D(sDiffuse, roundedUV);
	diffuseColorTex.a = texture2D(sDiffuse, roundedUV + vec2(0.0, 0.5)).r;
    lowp float alpha = diffuseColorTex.a;
    lowp vec4 diffuseColor =  diffuseColorTex;

    //ambient part
    lowp vec4 ambientColor = diffuseColor;

    ambientColor *= lightsAmbient;
    diffuseColor  *= dot(v_normal, lightsDirection);
    diffuseColor *= lightsDiffuse;

    mediump float D = dot(v_normal, specDirection);
    lowp vec4 specularColor = saturate(D * fMaterialSpecularLevel) * lightsSpecular;

    lowp vec4 result = diffuseColor  + ambientColor + specularColor;
    result = result * (vec4(1.0) - f4ClorSelfIllumination) + f4ClorSelfIllumination * diffuseColorTex;

    result.a = alpha;

    result *= mixColor;

    result.rgb = ((result.rgb - 0.5) * fContrast) + fBright + 0.5;

    result.rgb = mix(result.rgb, v_fogColor.rgb, v_fogFactor);
    gl_FragColor = result;
}
